<?php declare(strict_types=1);

namespace App\Controller;

use App\Entity\CameraType;
use App\Form\CameraTypeType;
use App\Traits\{DeleteFormTrait, FormControllerTrait};
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\{RedirectResponse, Request, Response};
use Symfony\Component\Routing\Annotation\Route;

#[Route(path: 'camera-type')]
class CameraTypeController extends AbstractController
{
    use FormControllerTrait;
    use DeleteFormTrait;

    protected const ENTITY        = CameraType::class;
    protected const TEMPLATE_PATH = 'cameratype/';
    protected const ROUTE_PREFIX  = 'camera-type_';
    protected const FORM          = CameraTypeType::class;

    public function __construct(private readonly EntityManagerInterface $entityManager)
    {
    }

    /**
     * Lists all cameraType entities.
     */
    #[Route(path: '/', name: 'camera-type_index', methods: ['GET'])]
    public function indexAction(): Response
    {
        return $this->itemListView('cameraTypes', [
            'type' => 'ASC',
        ]);
    }

    /**
     * Creates a new cameraType entity.
     */
    #[Route(path: '/new', name: 'camera-type_new', methods: ['GET', 'POST'])]
    public function newAction(Request $request): Response
    {
        return $this->itemCreate($request, 'cameraType');
    }

    /**
     * Finds and displays a cameraType entity.
     */
    #[Route(path: '/{id}', name: 'camera-type_show', methods: ['GET'])]
    public function showAction(CameraType $cameraType): Response
    {
        return $this->itemView($cameraType, 'cameraType');
    }

    /**
     * Displays a form to edit an existing cameraType entity.
     */
    #[Route(path: '/{id}/edit', name: 'camera-type_edit', methods: ['GET', 'POST'])]
    public function editAction(Request $request, CameraType $cameraType): RedirectResponse|Response
    {
        return $this->itemUpdate($request, $cameraType, 'cameraType');
    }

    /**
     * Deletes a cameraType entity.
     */
    #[Route(path: '/{id}', name: 'camera-type_delete', methods: ['POST', 'DELETE'])]
    public function deleteAction(Request $request, CameraType $cameraType): RedirectResponse
    {
        return $this->itemDelete($request, $cameraType);
    }
}
