<?php declare(strict_types=1);

namespace App\Controller;

use App\Entity\Flash;
use App\Form\FlashType;
use App\Traits\{DeleteFormTrait, FormControllerTrait};
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\{RedirectResponse, Request, Response};
use Symfony\Component\Routing\Annotation\Route;

/**
 * Flash controller.
 */
#[Route(path: 'flash')]
class FlashController extends AbstractController
{
    use FormControllerTrait;
    use DeleteFormTrait;

    protected const ENTITY        = Flash::class;
    protected const TEMPLATE_PATH = 'flash/';
    protected const ROUTE_PREFIX  = 'flash_';
    protected const FORM          = FlashType::class;

    public function __construct(private readonly EntityManagerInterface $entityManager)
    {
    }

    /**
     * Lists all flash entities.
     */
    #[Route(path: '/', name: 'flash_index', methods: ['GET'])]
    public function indexAction(): Response
    {
        return $this->itemListView('flashes');
    }

    /**
     * Creates a new flash entity.
     */
    #[Route(path: '/new', name: 'flash_new', methods: ['GET', 'POST'])]
    public function newAction(Request $request): RedirectResponse|Response
    {
        return $this->itemCreate($request, 'flash');
    }

    /**
     * Finds and displays a flash entity.
     */
    #[Route(path: '/{id}', name: 'flash_show', methods: ['GET'])]
    public function showAction(Flash $flash): Response
    {
        return $this->itemView($flash, 'flash');
    }

    /**
     * Displays a form to edit an existing flash entity.
     */
    #[Route(path: '/{id}/edit', name: 'flash_edit', methods: ['GET', 'POST'])]
    public function editAction(Request $request, Flash $flash): RedirectResponse|Response
    {
        return $this->itemUpdate($request, $flash, 'flash');
    }

    /**
     * Deletes a flash entity.
     */
    #[Route(path: '/{id}', name: 'flash_delete', methods: ['POST', 'DELETE'])]
    public function deleteAction(Request $request, Flash $flash): RedirectResponse
    {
        return $this->itemDelete($request, $flash);
    }
}
