<?php declare(strict_types=1);

namespace App\Entity;

use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;

/**
 * Camera
 */
#[ORM\Table(name: 'film', schema: 'collection')]
#[ORM\Entity]
class Film
{
    #[ORM\Id]
    #[ORM\Column(name: 'id', type: 'integer', nullable: FALSE)]
    #[ORM\GeneratedValue(strategy: 'IDENTITY')]
    private int $id;

    #[ORM\Column(name: 'brand', type: 'string', nullable: FALSE)]
    private string $brand;

    #[ORM\Column(name: 'product_line', type: 'string', nullable: TRUE)]
    private ?string $productLine = NULL;

    #[ORM\Column(name: 'film_name', type: 'string', nullable: FALSE)]
    private string $filmName;

    #[ORM\Column(name: 'film_alias', type: 'string', nullable: TRUE)]
    private ?string $filmAlias = NULL;

    #[ORM\Column(name: 'film_speed_asa', type: 'integer', nullable: FALSE)]
    private int $filmSpeedAsa;

    #[ORM\Column(name: 'film_speed_din', type: 'integer', nullable: FALSE)]
    private int $filmSpeedDin;

    #[ORM\Column(name: 'film_format', type: 'string', nullable: FALSE)]
    private string $filmFormat;

    #[ORM\Column(name: 'film_base', type: 'string', nullable: FALSE, options: ['default' => 'Cellulose Triacetate'])]
    private string $filmBase = 'Cellulose Triacetate';

    #[ORM\Column(name: 'unused_rolls', type: 'integer', nullable: FALSE, options: ['default' => 0])]
    private int $unusedRolls = 0;

    #[ORM\Column(name: 'rolls_in_camera', type: 'integer', nullable: FALSE, options: ['default' => 0])]
    private int $rollsInCamera = 0;

    #[ORM\Column(name: 'developed_rolls', type: 'integer', nullable: FALSE, options: ['default' => 0])]
    private int $developedRolls = 0;

    #[ORM\Column(name: 'chemistry', type: 'string', nullable: FALSE, options: ['default' => 'C-41'])]
    private string $chemistry = 'C-41';

    #[ORM\Column(name: 'notes', type: 'text', nullable: TRUE)]
    private ?string $notes = NULL;

    public function getId(): int
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getBrand(): ?string
    {
        return $this->brand;
    }

    public function setBrand(string $brand): self
    {
        $this->brand = $brand;

        return $this;
    }

    /**
     * @return string
     */
    public function getProductLine(): ?string
    {
        return $this->productLine;
    }

    /**
     * @param string $productLine
     */
    public function setProductLine(?string $productLine): self
    {
        $this->productLine = $productLine;

        return $this;
    }

    /**
     * @return string
     */
    public function getFilmName(): ?string
    {
        return $this->filmName;
    }

    public function setFilmName(string $filmName): self
    {
        $this->filmName = $filmName;

        return $this;
    }

    /**
     * @return string
     */
    public function getFilmAlias(): ?string
    {
        return $this->filmAlias;
    }

    public function setFilmAlias(string $filmAlias): self
    {
        $this->filmAlias = $filmAlias;

        return $this;
    }

    /**
     * @return int
     */
    public function getFilmSpeedAsa(): ?int
    {
        return $this->filmSpeedAsa;
    }

    public function setFilmSpeedAsa(int $filmSpeedAsa): self
    {
        $this->filmSpeedAsa = $filmSpeedAsa;

        return $this;
    }

    /**
     * @return int
     */
    public function getFilmSpeedDin(): ?int
    {
        return $this->filmSpeedDin;
    }

    public function setFilmSpeedDin(int $filmSpeedDin): self
    {
        $this->filmSpeedDin = $filmSpeedDin;

        return $this;
    }

    /**
     * @return string
     */
    public function getFilmFormat(): ?string
    {
        return $this->filmFormat;
    }

    public function setFilmFormat(string $filmFormat): self
    {
        $this->filmFormat = $filmFormat;

        return $this;
    }

    /**
     * @return string
     */
    public function getFilmBase(): ?string
    {
        return $this->filmBase;
    }

    public function setFilmBase(string $filmBase): self
    {
        $this->filmBase = $filmBase;

        return $this;
    }

    /**
     * @return int
     */
    public function getUnusedRolls(): ?int
    {
        return $this->unusedRolls;
    }

    public function setUnusedRolls(int $unusedRolls): self
    {
        $this->unusedRolls = $unusedRolls;

        return $this;
    }

    /**
     * @return int
     */
    public function getRollsInCamera(): ?int
    {
        return $this->rollsInCamera;
    }

    public function setRollsInCamera(int $rollsInCamera): self
    {
        $this->rollsInCamera = $rollsInCamera;

        return $this;
    }

    /**
     * @return int
     */
    public function getDevelopedRolls(): ?int
    {
        return $this->developedRolls;
    }

    public function setDevelopedRolls(int $developedRolls): self
    {
        $this->developedRolls = $developedRolls;

        return $this;
    }

    /**
     * @return string
     */
    public function getChemistry(): ?string
    {
        return $this->chemistry;
    }

    public function setChemistry(string $chemistry): self
    {
        $this->chemistry = $chemistry;

        return $this;
    }

    /**
     * @return string
     */
    public function getNotes(): ?string
    {
        return $this->notes;
    }

    public function setNotes(string $notes): self
    {
        $this->notes = $notes;

        return $this;
    }
}
